@@ -46,6 +46,11 @@
 #define TYPE_OTHER 	0
 #define ST_LOGIN	0
 #define ST_NOLOGIN	1
+#ifdef __CUSTOMIZE2018
+#define TEXT_ADDMSG	"addmsg"
+#define LEN_ADDMSG	sizeof(TEXT_ADDMSG)
+#define TYPE_ADDMSGRELOAD 	6
+#endif	// __CUSTOMIZE2018
 
 /* command output */
 #define OUTPUT_WELCOME "Welcome to SaMMA\n"
@@ -70,6 +75,10 @@
 #define LEN_OUTPUT_RELOAD_FAIL sizeof(OUTPUT_RELOAD_FAIL)
 #define LEN_OUTPUT_RELOAD_TMP_FAIL sizeof(OUTPUT_RELOAD_TMP_FAIL)
 #define LEN_OUTPUT_RELOAD_CFG_FAIL sizeof(OUTPUT_RELOAD_CFG_FAIL)
+#ifdef __CUSTOMIZE2018
+#define OUTPUT_RELOAD_ADDMSG_FAIL "reload failed(during reload)\n"
+#define LEN_OUTPUT_RELOAD_ADDMSG_FAIL sizeof(OUTPUT_RELOAD_ADDMSG_FAIL)
+#endif	// __CUSTOMIZE2018
 
 #define COMTIMEOUT	60000
 
