@@ -155,6 +155,7 @@ void init_harmless_proc_arg(harmless_proc_arg_t *args)
     args->depth = 0;
     args->cfg = NULL;
     args->maildata = NULL;
+    args->sendercheck = 0;
     args->mime_extension = NULL;
 }
 void free_harmless_proc_arg(harmless_proc_arg_t *args)
@@ -169,9 +170,11 @@ void free_harmless_proc_arg(harmless_proc_arg_t *args)
 
     args->depth = 0;
     args->maildata = NULL;
+    args->sendercheck = 0;
 
     free(args->mime_extension);
     args->mime_extension = NULL;
+
 }
 
 /**
@@ -201,6 +204,7 @@ int harmless(SMFICTX *ctx, struct mlfiPriv *priv)
     proc_arg.depth = cfg->cf_maxmultipartdepth;
     proc_arg.cfg = cfg;
     proc_arg.maildata = &(priv->mlfi_sendercheck_arg);
+    proc_arg.sendercheck = priv->mlfi_safetysendercheck;
 
     // GMime開始
     pthread_mutex_lock(&gmime_lock);
@@ -265,7 +269,11 @@ int harmless(SMFICTX *ctx, struct mlfiPriv *priv)
     // zipにすべきものがあれば作ってくっつける
     if (proc_arg.zipdir != NULL) {
         struct mailzip mz = {
+#ifndef __CUSTOMIZE2018
             NULL, NULL, NULL, proc_arg.zipdir, NULL, NULL, NULL
+#else   // __CUSTOMIZE2018
+            NULL, NULL, NULL, proc_arg.zipdir, NULL, NULL, NULL, 0, 0, NULL, NULL
+#endif  // __CUSTOMIZE2018
         };
         struct rcptinfo rinfo = {NULL, 0, NULL, NULL, NULL};
         struct rcptinfo *rinfo_list = &rinfo;
@@ -466,6 +474,7 @@ int harmless_proc(GMimeMultipart *parent, harmless_proc_arg_t *arg)
 {
     int index, i, ret;
 
+
     // multipart多重で再帰的に呼ばれるので、上限を決めておく
     if (arg->depth < 1) {
         log("Too deep multipart mail.(Max:%d)", arg->depth);
