@@ -192,7 +192,7 @@ void init_log();
 void switch_log(char *);
 void errorlog(char *, ...);
 void systemlog(char *, ...);
-int (*logfunc)(const char *, ...);
+extern int (*logfunc)(const char *, ...);
 
 #define log (*logfunc)
 
