@@ -38,7 +38,7 @@ conv_func_t msgconv_func_list[] = {
 /**
  * static function decraretion
  */
-int exec_command_with_gmime(GMimeObject *, GMimeObject **, char **, harmless_proc_arg_t *);
+int exec_command_with_gmime(GMimeObject *, GMimeObject **, char **, harmless_proc_arg_t *, int msg_next);
 
 void output_conv_log(char *fmt, char *command, sender_check_arg_t *data);
 
@@ -123,7 +123,7 @@ char *read_harmlessconf(char *file, void **pointer)
 
     for (nline = 1; fgets(line, MAX_CONFIG_LINE + 1, fp) != NULL; nline++) {
         command_list_t current_list = {NULL, NULL, NULL, NULL, 
-                                       -1, 0, 0, NULL, NULL};
+                                       -1, 0, 0, 0, NULL, NULL};
 
         tail = strchr(line, '\n');
         if (tail == NULL) {
@@ -172,6 +172,14 @@ char *read_harmlessconf(char *file, void **pointer)
             fth++;
         }
 
+        // 先頭の!の有無のチェック
+        if (*fth == '!') {
+            // 外部コマンド失敗のログ抑制フラグを立て、次のポインタへ
+            current_list.msg_next = 1;
+            fth++;
+        }
+
+
         // 指定されたコマンドのチェック
         if (*fth != '/') {
             current_list.command_type = FUNCTION;
@@ -392,17 +400,25 @@ char *read_mimetypes(char *filepath, void **pointer) {
 #define FILE_AFTER 3
 int msg_convert(GMimeObject *part, GMimeObject **new, harmless_proc_arg_t *arg)
 {
-    int ret;
-    char *content_type, *filename;
+    int ret, safety_flag;
+    char *content_type, *filename, *conf_file;
     struct strtag taglist[] = {
           { "mime-before", 11, NULL }
         , { "mime-after" , 10, NULL }
         , { "file-before", 11, NULL }
         , { "file-after" , 10, NULL }
     };
+    safety_flag = 0;
+
+    // sendercheckがOKの場合は、safetysenderharmlessconfを見るようにする
+    if (arg->sendercheck < 1) {
+        conf_file = arg->cfg->cf_harmlessconf;
+    } else {
+        conf_file = arg->cfg->cf_safetysenderharmlessconf;
+    }
 
     command_list_t *c_p;
-    command_list_t *command_list = arg->cfg->cf_harmlessconf;
+    command_list_t *command_list = conf_file;
 
     // convert_alternativeを通過していたら、取得したMIMEタイプを使用
     // 通過していない場合、メール本文から取得
@@ -445,6 +461,7 @@ int msg_convert(GMimeObject *part, GMimeObject **new, harmless_proc_arg_t *arg)
                 }
                 break;
             case COMMAND:
+                DEBUGLOG("case COMMMAND");
                 // ファイル名を環境変数に設定
                 if (setenv(ENV_FILENAME, filename, 1) != 0) {
                     output_conv_log(CONV_ERR_EXEC_ENV, c_p->command_name, arg->maildata);
@@ -452,9 +469,8 @@ int msg_convert(GMimeObject *part, GMimeObject **new, harmless_proc_arg_t *arg)
                     return HARMLESS_NG;
                 }
 
-                _ret = exec_command_with_gmime(part, new, c_p->arg_list, arg);
+                _ret = exec_command_with_gmime(part, new, c_p->arg_list, arg, c_p->msg_next);
                 if (_ret == HARMLESS_NG) {
-                    output_conv_log(CONV_ERR_EXEC_EXT, c_p->command_name, arg->maildata);
                     free(content_type);
                     return HARMLESS_NG;
                 }
@@ -464,6 +480,8 @@ int msg_convert(GMimeObject *part, GMimeObject **new, harmless_proc_arg_t *arg)
                     g_mime_object_set_content_type((GMimeObject *)*new, newtype);
                     g_object_unref(newtype);
                 }
+                // safetysenderharmless.confのMIMEtypeにマッチした
+                safety_flag = 1;
                 break;
         }
 
@@ -529,12 +547,20 @@ int convert_alternative(GMimeObject *part, GMimeObject **new, harmless_proc_arg_
 {
     int index, i;
     int alt_part = -1;
+    char *conf_file;
     char *content_type = NULL;
     GMimeMultipart *top;
 
-    command_list_t *cp;
-    command_list_t *clist = arg->cfg->cf_harmlessconf;
+    // sendercheckがOKの場合は、safetysenderharmlessconfを見るようにする
+    if (arg->sendercheck < 1) {
+        conf_file = arg->cfg->cf_harmlessconf;
+    } else {
+        conf_file = arg->cfg->cf_safetysenderharmlessconf;
+    }
 
+    command_list_t *cp;
+    //command_list_t *clist = arg->cfg->cf_harmlessconf;
+    command_list_t *clist = conf_file;
 
     if (!GMIME_IS_MULTIPART(part)) {
         return HARMLESS_NG;
@@ -701,7 +727,7 @@ int convert_extension(GMimeObject *part, GMimeObject **new, harmless_proc_arg_t
 /*
  * exec_command_with_gmime()
  */
-int exec_command_with_gmime(GMimeObject *part, GMimeObject **new, char **cmd_arg, harmless_proc_arg_t *arg)
+int exec_command_with_gmime(GMimeObject *part, GMimeObject **new, char **cmd_arg, harmless_proc_arg_t *arg, int msg_next)
 {
     char *after = NULL;
     size_t aftersize;
@@ -712,7 +738,7 @@ int exec_command_with_gmime(GMimeObject *part, GMimeObject **new, char **cmd_arg
     }
 
 
-    int eret = exec_external(part, cmd_arg, &after, &aftersize, arg->maildata, arg->cfg->cf_harmlesscommandtimeout);
+    int eret = exec_external(part, cmd_arg, &after, &aftersize, arg->maildata, arg->cfg->cf_harmlesscommandtimeout, msg_next);
 
     if (eret != EXEC_EXTERNAL_SUCCESS) {
         return HARMLESS_NG;
