@@ -227,7 +227,7 @@ search_rcptaddr(struct config *cfg, char *sender, struct rcptaddr *rcptlist, str
         user_policy = ENC;
 
         /* ldapserver connect */
-        res.ld = ldap_connect(cfg->cf_ldapuri, cfg->cf_ldapbinddn, 
+        res.ld = myldap_connect(cfg->cf_ldapuri, cfg->cf_ldapbinddn, 
                 cfg->cf_ldapbindpassword);
         if (res.ld == NULL) {
             free_search_rcptaddr(&res);
@@ -1398,7 +1398,7 @@ ldap_search_policy (LDAP *ld, char *ldapbasedn, char *rcpt, char *userdn, struct
 }
 
 /*
- * ldap_connect
+ * myldap_connect
  *
  * Args:
  *      char *uri                   connect uri  
@@ -1410,7 +1410,7 @@ ldap_search_policy (LDAP *ld, char *ldapbasedn, char *rcpt, char *userdn, struct
  *      NULL
  */
 LDAP *
-ldap_connect(char *uri, char *ldapbinddn, char *ldapbindpass)
+myldap_connect(char *uri, char *ldapbinddn, char *ldapbindpass)
 {
     LDAP *ld;
     int ret;
@@ -1422,7 +1422,7 @@ ldap_connect(char *uri, char *ldapbinddn, char *ldapbindpass)
     ret = ldap_initialize(&ld, uri);
     if (ret != LDAP_SUCCESS) {
         ldap_get_option(ld, LDAP_OPT_RESULT_CODE, &lderrno);
-        log(ERR_LDAP_INIT, "ldap_connect", ldap_err2string(lderrno));
+        log(ERR_LDAP_INIT, "myldap_connect", ldap_err2string(lderrno));
         return(NULL);
     }
 
@@ -1434,7 +1434,7 @@ ldap_connect(char *uri, char *ldapbinddn, char *ldapbindpass)
     ret = ldap_set_option(ld, LDAP_OPT_NETWORK_TIMEOUT, &tval);
     if (ret != LDAP_SUCCESS) {
         ldap_get_option(ld, LDAP_OPT_RESULT_CODE, &lderrno);
-        log(ERR_LDAP_SET, "ldap_connect", ldap_err2string(lderrno));
+        log(ERR_LDAP_SET, "myldap_connect", ldap_err2string(lderrno));
         return(NULL);
     }
 
@@ -1445,7 +1445,7 @@ ldap_connect(char *uri, char *ldapbinddn, char *ldapbindpass)
     ret = ldap_sasl_bind_s(ld, ldapbinddn, LDAP_SASL_SIMPLE, &bv, NULL, NULL, NULL);
     if (ret != LDAP_SUCCESS) {
         ldap_get_option(ld, LDAP_OPT_RESULT_CODE, &lderrno);
-        log(ERR_LDAP_BIND, "ldap_connect", ldap_err2string(lderrno));
+        log(ERR_LDAP_BIND, "myldap_connect", ldap_err2string(lderrno));
         return(NULL);
     }
 
