@@ -85,7 +85,7 @@ int search_subdomain_bdb(DB *, const char *, char *, char **, char **);
 int mk_passwd(char **, int);
 int search_str_bdb(DB *, const char *, char *, char *, char **);
 int make_filter (char *, char **);
-LDAP * ldap_connect(char *, char *, char *);
+LDAP * myldap_connect(char *, char *, char *);
 int ldap_search_policy(LDAP *, char *, char *, char*, struct person *);
 int ldap_get_userdn(LDAP *, char *, char *, char *, char *, char **);
 int search_rcptaddr_bdb(struct search_res *, struct config *, char *, struct rcptinfo **, struct rcptinfo **);
