@@ -162,6 +162,7 @@ int check_sender(struct mlfiPriv *priv)
         ret = (c_func->function)(data);
         switch (ret) {
             case SENDER_CHECK_OK:
+            case SENDER_CHECK_NONE:
             case SENDER_CHECK_ERR:
                 return ret;
             case SENDER_CHECK_NG:
@@ -543,5 +544,5 @@ int check_none(sender_check_arg_t *data)
 {
     log(LOG_HARMLESS, data->ip, data->message_id, data->envelope_from, data->rcpt_to);
 
-    return SENDER_CHECK_OK;
+    return SENDER_CHECK_NONE;
 };
