@@ -1395,6 +1395,7 @@ DEBUGLOG("Failed to get filename when index = %d", i);
 	free(tmpname);
         if (validatename != NULL) {
             free(validatename);
+            validatename = NULL;
         }
 
         if (ismode_delete) {
@@ -1630,8 +1631,11 @@ convert_zip(struct config *cfg, struct mailzip *mz, struct rcptinfo *rcpt)
 #ifndef __CUSTOMIZE2018
         zip_child(list, cfg->cf_zipcommandopt, mz->zipdir, rcpt->passwd);
 #else   // __CUSTOMIZE2018
-        zip_child(list, cfg->cf_zipcommandopt, mz->zipdir, rcpt->passwd,
-                    mz->am_priv->mlfi_savefrom);
+        if (ismode_harmless) {
+            zip_child(list, cfg->cf_zipcommandopt, mz->zipdir, rcpt->passwd,NULL);
+        } else {
+            zip_child(list, cfg->cf_zipcommandopt, mz->zipdir, rcpt->passwd, mz->am_priv->mlfi_savefrom);
+        }
 #endif  // __CUSTOMIZE2018
     } else if (pid > 0) {
         /* parent process */
@@ -1687,7 +1691,7 @@ zip_child(char **list, char *commandopt, char *dir, char *passwd, char *from)
     }
     free(envstr);
 #ifdef __CUSTOMIZE2018
-    if (setenv(ENV_SAMMA_ENVFROM, from, OVERWRITE) < 0) {
+    if (from && setenv(ENV_SAMMA_ENVFROM, from, OVERWRITE) < 0) {
         log(ERR_SET_ENV, "zip_child", ENV_SAMMA_ENVFROM);
         exit(1);
     }
